// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent

    property int itemPriority: 0

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal triggered(int newPriority);

    property color tabPanelMarkerColor: "#639fff"
    property Gradient tabPanelBackgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.5; color: "#dddddd" }
        GradientStop { position: 1.0; color: "white" }
    }

    onItemPriorityChanged: {
        detailsPanel.selectTab(itemPriority)
        triggered(itemPriority)
    }

    Rectangle {
        id: detailsPanel
        anchors.fill: parent

        color: "transparent"

        property int tabWidths: 100
        property int tabHeights: 21
        property int tabCount: 4

        property int tabStartPos: (detailsPanel.width / 2 - (detailsPanel.tabCount * detailsPanel.tabWidths / 2))

        function selectTab(tab) {
            tab0.isSelected = false
            tab1.isSelected = false
            tab2.isSelected = false
            tab3.isSelected = false

            if (tab === 0) tab0.isSelected = true
            if (tab === 1) tab1.isSelected = true
            if (tab === 2) tab2.isSelected = true
            if (tab === 3) tab3.isSelected = true
        }

        AIInspectorTabPanelTab {
            id: tab0
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos

            backgroundColor: "white"
            selectionColor: tabPanelMarkerColor

            text: qsTr("Low")
            icon: "qrc:/icons/PriorityDotsLow.png"
//            iconVisible: true
            isSelected: true

            onTriggered: {
                console.debug("Low triggered.")
//                detailsPanel.selectTab(0)
                itemPriority = 0
            }
        }

        AIInspectorTabPanelTab {
            id: tab1
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + width

            backgroundColor: "white"
            selectionColor: tabPanelMarkerColor

            text: qsTr("Normal")
            icon: "qrc:/icons/PriorityDotsNormal.png"

            onTriggered: {
                console.debug("Normal triggered.")
//                detailsPanel.selectTab(1)
                itemPriority = 1
            }
        }

        AIInspectorTabPanelTab {
            id: tab2
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + width * 2

            backgroundColor: "white"
            selectionColor: tabPanelMarkerColor

            text: qsTr("Medium")
            icon: "qrc:/icons/PriorityDotsMedium.png"

            onTriggered: {
                console.debug("Medium triggered.")
//                detailsPanel.selectTab(2)
                itemPriority = 2
            }
        }

        AIInspectorTabPanelTab {
            id: tab3
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + width * 3

            backgroundColor: "white"
            selectionColor: tabPanelMarkerColor

            text: qsTr("High")
            icon: "qrc:/icons/PriorityDotsHigh.png"

            onTriggered: {
                console.debug("High triggered.")
//                detailsPanel.selectTab(3)
                itemPriority = 3
            }
        }
    }
}
